﻿using System;
using System.IO;
using Microsoft.AspNetCore.Mvc;
using GdPicture14.WEB;
using DocuViewareDemo.Models;
using System.Net.Http;

namespace DocuViewareDemo.Controllers
{
    [ApiController]
    [Route("api/DocuVieware")]
    public class DocuViewareController : ControllerBase
    {
        [HttpPost]
        [Route("GetDocuViewareControl")]
        public DocuViewareRESTOutputResponse GetDocuViewareControl(DocuViewareConfiguration controlConfiguration)
        {
            if (!DocuViewareManager.IsSessionAlive(controlConfiguration.SessionId))
            {
                if (!string.IsNullOrEmpty(controlConfiguration.SessionId) && !string.IsNullOrEmpty(controlConfiguration.ControlId))
                {
                    DocuViewareManager.CreateDocuViewareSession(controlConfiguration.SessionId, controlConfiguration.ControlId, 20);
                }
                else
                {
                    throw new Exception("Invalid session identifier and/or invalid control identifier.");
                }
            }

            using (DocuViewareControl docuVieware = new DocuViewareControl(controlConfiguration.SessionId))
            {
                docuVieware.AllowPrint = controlConfiguration.AllowPrint;
                docuVieware.EnablePrintButton = controlConfiguration.EnablePrintButton;
                docuVieware.AllowUpload = controlConfiguration.AllowUpload;
                docuVieware.EnableFileUploadButton = controlConfiguration.EnableFileUploadButton;
                docuVieware.CollapsedSnapIn = controlConfiguration.CollapsedSnapIn;
                docuVieware.ShowAnnotationsSnapIn = controlConfiguration.ShowAnnotationsSnapIn;
                docuVieware.EnableRotateButtons = controlConfiguration.EnableRotateButtons;
                docuVieware.EnableZoomButtons = controlConfiguration.EnableZoomButtons;
                docuVieware.EnablePageViewButtons = controlConfiguration.EnablePageViewButtons;
                docuVieware.EnableMultipleThumbnailSelection = controlConfiguration.EnableMultipleThumbnailSelection;
                docuVieware.EnableMouseModeButtons = controlConfiguration.EnableMouseModeButtons;
                docuVieware.EnableFormFieldsEdition = controlConfiguration.EnableFormFieldsEdition;
                docuVieware.EnableTwainAcquisitionButton = controlConfiguration.EnableTwainAcquisitionButton;
                docuVieware.MaxUploadSize = 36700160; // 35MB

                using (StringWriter controlOutput = new StringWriter())
                {
                    docuVieware.RenderControl(controlOutput);
                    DocuViewareRESTOutputResponse output = new DocuViewareRESTOutputResponse
                    {
                        HtmlContent = controlOutput.ToString()
                    };
                    return output;
                }
            }
        }

        [HttpPost("init")]
        public string Init([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.init(jsonString);
        }

        [HttpPost("close")]
        public string Close([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.close(jsonString);
        }

        [HttpPost("selectpage")]
        public string SelectPage([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.selectpage(jsonString);
        }

        [HttpPost("rotate")]
        public string Rotate([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.rotate(jsonString);
        }

        [HttpPost("bookmarks")]
        public string Bookmarks([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.bookmarks(jsonString);
        }

        [HttpPost("thumbnails")]
        public string Thumbnails([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.thumbnails(jsonString);
        }

        [HttpPost("pageview")]
        public string PageView([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.pageview(jsonString);
        }

        [HttpPost("rundestination")]
        public string RunDestination([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.rundestination(jsonString);
        }

        [HttpPost("textsearch")]
        public string TextSearch([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.textsearch(jsonString);
        }

        [HttpPost("zoommode")]
        public string ZoomMode([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.zoommode(jsonString);
        }

        [HttpPost("zoomset")]
        public string ZoomSet([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.zoomset(jsonString);
        }

        [HttpPost("singlepageviewmode")]
        public string SinglePageViewMode([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.singlepageviewmode(jsonString);
        }

        [HttpPost("zoomin")]
        public string ZoomIn([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.zoomin(jsonString);
        }

        [HttpPost("zoomout")]
        public string ZoomOut([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.zoomout(jsonString);
        }

        [HttpPost("zoomrect")]
        public string ZoomRect([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.zoomrect(jsonString);
        }

        [HttpPost("newannotation")]
        public string NewAnnotation([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.newannotation(jsonString);
        }

        [HttpPost("newannotationcomment")]
        public string NewAnnotationComment([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.newannotationcomment(jsonString);
        }

        [HttpPost("print")]
        public string Print([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.print(jsonString);
        }

        [HttpPost("customaction")]
        public string CustomAction([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.customaction(jsonString);
        }

        [HttpGet("print")]
        public HttpResponseMessage Print(string sessionID, string pageRange, bool printAnnotations)
        {
            return DocuViewareControllerActionsHandler.print(sessionID, pageRange, printAnnotations);
        }

        [HttpGet("save")]
        public HttpResponseMessage Save(string sessionID, string fileName, string format, string pageRange)
        {
            return DocuViewareControllerActionsHandler.save(sessionID, fileName, format, pageRange);
        }

        [HttpGet("twainservicesetupdownload")]
        public HttpResponseMessage TwainServiceSetupDownload(string sessionID)
        {
            return DocuViewareControllerActionsHandler.twainservicesetupdownload(sessionID);
        }

        [HttpPost("formfieldupdate")]
        public string FormfieldUpdate([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.formfieldupdate(jsonString);
        }

        [HttpPost("annotupdate")]
        public string AnnotUpdate([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.annotupdate(jsonString);
        }

        [HttpPost("loadfromuri")]
        public string LoadFromUri([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.loadfromuri(jsonString);
        }

        [HttpPost("loadfromfile")]
        public string LoadFromFile([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.loadfromfile(jsonString);
        }

        [HttpPost("setpassword")]
        public string SetPassword([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.setpassword(jsonString);
        }

        [HttpPost("movepage")]
        public string MovePage([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.movepage(jsonString);
        }

        [HttpPost("redact")]
        public string Redact([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.redact(jsonString);
        }

        [HttpPost("digisign")]
        public string Digisign([FromBody]object jsonString)
        {
            return DocuViewareControllerActionsHandler.digisign(jsonString);
        }
    }
}
